==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Select/SelectIntersectedEntities/ts/SelectIntersectedEntities_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>SelectIntersectedEntities</name>
    <message>
        <location filename="../SelectIntersectedEntities.js" line="+89"/>
        <source>First point</source>
        <translatorcomment>--google--
Wskaż pierwszy punkt
Wskaż pierwszy punkt wieloboku
Wskaż pierwszy punkt odległości</translatorcomment>
        <translation type="unfinished">Pierwszy punkt</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Second point</source>
        <translatorcomment>--google--
Wskaż drugi punkt
Wskaż dugi punkt odległości
Wskaż drugi punkt linii odbicia</translatorcomment>
        <translation type="unfinished">Drugi punkt</translation>
    </message>
    <message>
        <location filename="../SelectIntersectedEntities.ui" line="+17"/>
        <source>Mode:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Tryb:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Replace the current selection</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Zamień bieżące zaznaczenie</translation>
    </message>
    <message>
        <location line="+16"/>
        <location line="+20"/>
        <location line="+20"/>
        <location line="+20"/>
        <source>SelectionMode</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">SelectionMode</translation>
    </message>
    <message>
        <location line="-53"/>
        <source>Add to the current selection</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Dodać do wyboru bieżących</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Subtract from the current selection</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Odejmij od bieżącego zaznaczenia</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Intersect with the current selection</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Przecięcie z bieżącego zaznaczenia</translation>
    </message>
    <message>
        <location filename="../SelectIntersectedEntitiesInit.js" line="+2"/>
        <source>(De-)Select In&amp;tersected Entities</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">(De-) Wybierz przecięte Podmioty</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>(De-)Select all entities intersected by a line</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">(De-) Wybierz wszystkie podmioty przecięte przez linię</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Select/SelectIntersectedEntities/ts/SelectIntersectedEntities_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>SelectIntersectedEntities</name>
    <message>
        <location filename="../SelectIntersectedEntities.js" line="+89"/>
        <source>First point</source>
        <translatorcomment>--google--
Wskaż pierwszy punkt
Wskaż pierwszy punkt wieloboku
Wskaż pierwszy punkt odległości</translatorcomment>
        <translation>Pierwszy punkt</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Second point</source>
        <translatorcomment>--google--
Wskaż drugi punkt
Wskaż dugi punkt odległości
Wskaż drugi punkt linii odbicia</translatorcomment>
        <translation>Drugi punkt</translation>
    </message>
    <message>
        <location filename="../SelectIntersectedEntities.ui" line="+17"/>
        <source>Mode:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Tryb:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Replace the current selection</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Zamień aktualne zaznaczenie</translation>
    </message>
    <message>
        <location line="+16"/>
        <location line="+20"/>
        <location line="+20"/>
        <location line="+20"/>
        <source>SelectionMode</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>TrybZaznaczania</translation>
    </message>
    <message>
        <location line="-53"/>
        <source>Add to the current selection</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Dodaj do aktualnego zaznaczenia</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Subtract from the current selection</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Odejmij od aktualnego zaznaczenia</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Intersect with the current selection</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Wyznacz część wspólną z aktualnym zaznaczeniem</translation>
    </message>
    <message>
        <location filename="../SelectIntersectedEntitiesInit.js" line="+2"/>
        <source>(De-)Select In&amp;tersected Entities</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Zaznacz pr&amp;zecięte obiekty</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>(De-)Select all entities intersected by a line</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Zaznacza lub odznacza wszystkie obiekty przecięte linią</translation>
    </message>
</context>
</TS>
